<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\View\Welcome\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

/** @var HtmlView $this */

$softwareName          = 'Akeeba LoginGuard';
$minPHPVersion         = '7.2.0';
$class_priority_low    = 'alert alert-info';
$class_priority_medium = 'alert alert-warning';
$class_priority_high   = 'alert alert-danger';

require_once JPATH_COMPONENT_ADMINISTRATOR . '/tmpl/common/wrongphp.php';

?>
<?php if ($this->noMethods || $this->notInstalled || $this->noSystemPlugin): ?>
	<div class="alert alert-error">
		<span class="badge bg-important bg-danger">
			<?= Text::_('COM_LOGINGUARD_STATUS_NOTREADY'); ?>
		</span>
		<?= Text::_('COM_LOGINGUARD_STATUS_NOTREADY_INFO'); ?>
	</div>
<?php elseif ($this->noUserPlugin): ?>
	<div class="alert alert-warning">
		<span class="badge bg-warning">
		<?= Text::_('COM_LOGINGUARD_STATUS_ALMOSTREADY'); ?>
		</span>
		<?= Text::_('COM_LOGINGUARD_STATUS_ALMOSTREADY_INFO'); ?>
	</div>
<?php else: ?>
	<div class="alert alert-success">
		<span class="badge bg-success">
			<?= Text::_('COM_LOGINGUARD_STATUS_READY'); ?>
		</span>
		<?= Text::_('COM_LOGINGUARD_STATUS_READY_INFO'); ?>
	</div>
<?php endif; ?>

<?php if ($this->notInstalled): ?>
	<div class="alert alert-warning">
		<h2 class="alert-heading">
			<span class="icon icon-power-cord" aria-hidden="true"></span>
			<?= Text::_('COM_LOGINGUARD_ERR_NOPLUGINS_HEAD'); ?>
		</h2>
		<p>
			<?= Text::_('COM_LOGINGUARD_ERR_PLUGINS_INFO_COMMON'); ?>
			<?= Text::_('COM_LOGINGUARD_ERR_NOPLUGINS_INFO'); ?>
		</p>
	</div>
<?php elseif ($this->noMethods): ?>
	<div class="alert alert-warning">
		<h2 class="alert-heading">
			<span class="icon icon-warning-2 icon-warning-sign" aria-hidden="true"></span>
			<?= Text::_('COM_LOGINGUARD_ERR_NOTINSTALLEDPLUGINS_HEAD'); ?>
		</h2>
		<p>
			<?= Text::_('COM_LOGINGUARD_ERR_PLUGINS_INFO_COMMON'); ?>
			<?= Text::_('COM_LOGINGUARD_ERR_NOTINSTALLEDPLUGINS_INFO'); ?>
		</p>
	</div>
<?php endif; ?>

<?php if ($this->noSystemPlugin): ?>
	<div class="alert alert-warning">
		<h2 class="alert-heading">
			<span class="icon icon-warning-2 icon-warning-sign" aria-hidden="true"></span>
			<?= Text::_('COM_LOGINGUARD_ERR_NOSYSTEM_HEAD'); ?>
		</h2>
		<p>
			<?= Text::_('COM_LOGINGUARD_ERR_NOSYSTEM_INFO'); ?>
		</p>
	</div>
<?php endif; ?>

<?php if ($this->noUserPlugin): ?>
	<div class="alert alert-warning">
		<h2 class="alert-heading">
			<span class="icon icon-warning-2 icon-warning-sign" aria-hidden="true"></span>
			<?= Text::_('COM_LOGINGUARD_ERR_NOUSER_HEAD'); ?>
		</h2>
		<p>
			<?= Text::_('COM_LOGINGUARD_ERR_NOUSER_INFO'); ?>
		</p>
	</div>
<?php endif; ?>

<?php if ($this->needsMigration && !$this->notInstalled && !$this->noMethods && !$this->noSystemPlugin): ?>
	<div class="alert alert-info">
		<h2 class="alert-heading">
			<span class="icon icon-lock" aria-hidden="true"></span>
			<?= Text::_('COM_LOGINGUARD_LBL_CONVERT_HEAD'); ?>
		</h2>
		<p>
			<?= Text::_('COM_LOGINGUARD_LBL_CONVERT_INFO'); ?>
		</p>
		<p>
			<a class="btn btn-success btn-lg"
			   href="<?= Route::_('index.php?option=com_loginguard&task=convert.Convert&' . Factory::getApplication()->getSession()->getToken() . '=1') ?>">
				<span class="icon icon-apply" aria-hidden="true"></span>
				<?= Text::_('COM_LOGINGUARD_BTN_CONVERT'); ?>
			</a>
		</p>
	</div>
<?php endif; ?>

<div class="card">
	<h2 class="card-header bg-info text-white">
		<?= Text::_('COM_LOGINGUARD_LBL_MANAGE_HEAD'); ?>
	</h2>
	<div class="card-body">
		<p>
			<?= Text::_('COM_LOGINGUARD_LBL_MANAGE_BODY'); ?>
		</p>
		<p>
			<a class="btn btn-primary btn-large btn-lg me-3"
			   href="<?= Route::_('index.php?option=com_loginguard&task=methods.display') ?>">
				<span class="icon icon-lock" aria-hidden="true"></span>
				<?= Text::_('COM_LOGINGUARD_BTN_MANAGE_SELF'); ?>
			</a>
			<a class="btn btn-default btn-outline-secondary" href="<?= Route::_('index.php?option=com_loginguard&view=users') ?>">
				<span class="icon icon-users" aria-hidden="true"></span>
				<?= Text::_('COM_LOGINGUARD_BTN_MANAGE_OTHERS'); ?>
			</a>
		</p>
	</div>
</div>