<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\View\Method\HtmlView;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

/** @var  HtmlView  $this */

HTMLHelper::_('bootstrap.tooltip', '.hasTooltip');

$cancelURL = Route::_('index.php?option=com_loginguard&task=methods.display&user_id=' . $this->user->id);

if (!empty($this->returnURL))
{
	$cancelURL = $this->escape(base64_decode($this->returnURL));
}

$recordId = (int) $this->record->id ?? 0;
$method   = $this->record->method ?? $this->getModel()->getState('method');
$userId   = (int) $this->user->id ?? 0;
?>
<div id="loginguard-method-edit-container">
	<form action="<?= Route::_(sprintf("index.php?option=com_loginguard&task=method.save&id=%d&method=%s&user_id=%d", $recordId, $method, $userId)) ?>"
		  id="loginguard-method-edit" method="post">

		<?= HTMLHelper::_('form.token') ?>
		<?php if (!empty($this->returnURL)): ?>
		<input type="hidden" name="returnurl" value="<?= $this->escape($this->returnURL) ?>">
		<?php endif; ?>

		<?php if (!empty($this->renderOptions['hidden_data'])): ?>
		<?php foreach ($this->renderOptions['hidden_data'] as $key => $value): ?>
		<input type="hidden" name="<?= $this->escape($key) ?>" value="<?= $this->escape($value) ?>">
		<?php endforeach; ?>
		<?php endif; ?>

		<?php if (!empty($this->title)): ?>
		<div id="loginguard-method-edit-title-container">
			<?php if (!empty($this->renderOptions['help_url'])): ?>
			<div id="loginguard-method-edit-title-help">
				<a href="<?= $this->renderOptions['help_url'] ?>"
				   class="loginguard-button-ghost-small"
				   target="_blank"
				>
					<span class="icon icon-question-sign" aria-hidden="true"></span>
					<span class="loginguard-visually-hidden"><?= Text::_('COM_LOGINGUARD_LBL_HELP') ?></span>
				</a>
			</div>
			<?php endif;?>

			<h3 id="loginguard-method-edit-head">
				<?= Text::_($this->title) ?>
			</h3>
		</div>
		<?php endif; ?>

		<div class="loginguard-form-input-container">
			<label class="loginguard-form-input-label hasTooltip"
				for="loginguard-method-edit-title"
				title="<?= $this->escape(Text::_('COM_LOGINGUARD_LBL_EDIT_FIELD_TITLE_DESC')) ?>">
				<?= Text::_('COM_LOGINGUARD_LBL_EDIT_FIELD_TITLE'); ?>
			</label>
			<div class="loginguard-form-input loginguard-form-input-title">
				<input type="text"
						id="loginguard-method-edit-title"
						name="title"
						value="<?= $this->escape($this->record->title) ?>"
						placeholder="<?= Text::_('COM_LOGINGUARD_LBL_EDIT_FIELD_TITLE_DESC') ?>">
			</div>
		</div>

		<div class="loginguard-form-input-container">
			<div class="loginguard-form-input-check">
				<input type="checkbox" id="loginguard-is-default-method" <?= $this->record->default ? 'checked="checked"' : ''; ?> name="default">
				<label class="loginguard-form-input-label" for="loginguard-is-default-method">
					<?= Text::_('COM_LOGINGUARD_LBL_EDIT_FIELD_DEFAULT'); ?>
				</label>
			</div>
		</div>

		<?php if (!empty($this->renderOptions['pre_message'])): ?>
		<div class="loginguard-method-edit-pre-message">
			<?= $this->renderOptions['pre_message'] ?>
		</div>
		<?php endif; ?>

		<?php if (!empty($this->renderOptions['tabular_data'])): ?>
		<div class="loginguard-method-edit-tabular-container">
			<?php if (!empty($this->renderOptions['table_heading'])): ?>
			<h4>
				<?= $this->renderOptions['table_heading'] ?>
			</h4>
			<?php endif; ?>
			<table>
				<tbody>
				<?php foreach ($this->renderOptions['tabular_data'] as $cell1 => $cell2): ?>
				<tr>
					<th scope="row">
						<?= $cell1 ?>
					</th>
					<td>
						<?= $cell2 ?>
					</td>
				</tr>
				<?php endforeach; ?>
				</tbody>
			</table>
		</div>
		<?php endif; ?>

		<?php if ($this->renderOptions['field_type'] == 'custom'): ?>
			<?= $this->renderOptions['html']; ?>
		<?php else: ?>
		<div class="loginguard-form-input-container">
			<?php if ($this->renderOptions['label']): ?>
			<label class="loginguard-form-input-label hasTooltip" for="loginguard-method-edit-code">
				<?= $this->renderOptions['label']; ?>
			</label>
			<?php endif; ?>
			<div class="loginguard-form-input" <?= $this->renderOptions['label'] ? '' : 'offset-sm-3' ?>>
				<input type="<?= $this->renderOptions['input_type']; ?>"
					   class="form-control" id="loginguard-method-code"
					   name="code"
					   value="<?= $this->escape($this->renderOptions['input_value']) ?>"
					   placeholder="<?= $this->escape($this->renderOptions['placeholder']) ?>">
			</div>
		</div>
		<?php endif; ?>

		<div id="loginguard-method-edit-buttons">
			<?php if ($this->renderOptions['show_submit'] || $this->isEditExisting): ?>
			<button type="submit" class="loginguard-button-primary-large">
				<span class="icon icon-ok" aria-hidden="true"></span>
				<?= Text::_('COM_LOGINGUARD_LBL_EDIT_SUBMIT'); ?>
			</button>
			<?php endif; ?>

			<a href="<?= $cancelURL ?>"
			   class="loginguard-button-danger">
				<span class="icon icon-cancel-2" aria-hidden="true"></span>
				<?= Text::_('COM_LOGINGUARD_LBL_EDIT_CANCEL'); ?>
			</a>
		</div>

		<?php if (!empty($this->renderOptions['post_message'])): ?>
			<div class="loginguard-method-edit-post-message">
				<?= $this->renderOptions['post_message'] ?>
			</div>
		<?php endif; ?>
	</form>
</div>